@@ -4,16 +4,10 @@
 import hashlib
 import hmac
 import requests
-import six
 import time
 from operator import itemgetter
 from .exceptions import BinanceAPIException, BinanceRequestException, BinanceWithdrawException
 
-if six.PY2:
-    from urllib import urlencode
-elif six.PY3:
-    from urllib.parse import urlencode
-
 
 class Client(object):
 
@@ -1383,9 +1377,11 @@ class Client(object):
         :type asset: str
         :type address: required
         :type address: str
+        :type addressTag: optional - Secondary address identifier for coins like XRP,XMR etc.
+        :type address: str
         :param amount: required
         :type amount: decimal
-        :param name: Description of the address - optional
+        :param name: optional - Description of the address, default asset value passed will be used
         :type name: str
         :param recvWindow: the number of milliseconds the request is valid for
         :type recvWindow: int
@@ -1396,12 +1392,16 @@ class Client(object):
 
             {
                 "msg": "success",
-                "success": true
+                "success": true,
+                "id":"7213fea8e94b4a5593d507237e5a555b"
             }
 
         :raises: BinanceResponseException, BinanceAPIException, BinanceWithdrawException
 
         """
+        # force a name for the withdrawal if one not set
+        if 'asset' in params and 'name' not in params:
+            params['name'] = params['asset']
         res = self._request_withdraw_api('post', 'withdraw.html', True, data=params)
         if not res['success']:
             raise BinanceWithdrawException(res['msg'])
